@@ -40,6 +40,8 @@ DLLLOCAL QoreStringNode* jni_module_init_intern();
 
 namespace jni {
 
+constexpr const char* JAVA_QORE_CLASS_FIELD = "$qore_cls_ptr";
+
 enum class Type {
     Void, Boolean, Byte, Char, Short, Int, Long, Float, Double, Reference
 };
@@ -117,6 +119,7 @@ public:
     DLLLOCAL static jmethodID methodFieldGetModifiers;                            // int Field.getModifiers()
     DLLLOCAL static jmethodID methodFieldGetName;                                 // String Field.getName()
     DLLLOCAL static jmethodID methodFieldGet;                                     // Object Field.get(Object)
+    DLLLOCAL static jmethodID methodFieldGetLong;                                 // Object Field.getLong(Object)
     DLLLOCAL static jmethodID methodFieldSetAccessible;                           // void Field.setAccessible(boolean)
 
     DLLLOCAL static GlobalReference<jclass> classMethod;                          // java.lang.reflect.Method
@@ -169,6 +172,7 @@ public:
     DLLLOCAL static GlobalReference<jclass> classQoreObjectWrapper;               // org.qore.jni.QoreObjectWrapper
 
     DLLLOCAL static GlobalReference<jclass> classQoreClosureMarker;               // org.qore.jni.QoreClosureMarker
+    DLLLOCAL static GlobalReference<jclass> classQoreClosureMarkerImpl;           // org.qore.jni.QoreClosureMarkerImpl
 
     DLLLOCAL static GlobalReference<jclass> classProxy;                           // java.lang.reflect.Proxy
     DLLLOCAL static jmethodID methodProxyNewProxyInstance;                        // Object Proxy.newProxyInstance(ClassLoader, Class[], InvocationHandler)
@@ -307,6 +311,8 @@ public:
     DLLLOCAL static GlobalReference<jclass> classBooleanWrapper;                  // org.qore.jni.BooleanWrapper
     DLLLOCAL static jmethodID methodBooleanWrapperSetTrue;                        // setTrue()
 
+    DLLLOCAL static GlobalReference<jstring> javaQoreClassField;
+
     DLLLOCAL static GlobalReference<jclass> getQoreJavaClassBase(Env& env, jobject classLoader);
 
     // returns true if this is a Java bootstrap init
